---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]
If applicable, attach screenshots or additional context.

**Proposed solution & alternatives considered**

- A clear and concise description of what you want to happen.
- A clear and concise description of any alternative solutions or features you've considered.
